Learn R Programming

nlstac (version 0.2.0)

is.nlstac: Is nlsTAC class check

Description

Checks wether an R object is of tac class or not.

Usage

is.nlstac(x)

Value

Returns TRUE if its argument is a tac object (that is, has "tac" amongst its classes) and FALSE otherwise.

Arguments

x

Any R object.