Returns the variance-covariance matrix of the main parameters of a fitted model object. The “main” parameters of model correspond to those returned by coef,
# S3 method for nlstac
vcov(object, ...)A matrix of the estimated covariances between the parameter estimates.
An object of class "nlstac" obtained by the nls_tac function.
Ignored, for compatibility issues.
Mariano Rodríguez-Arias (arias@unex.es). Deptartment of Mathematics
Juan Antonio Fernández Torvisco (jfernandck@alumnos.unex.es). Department of Mathematics
University of Extremadura (Spain)
Rafael Benítez (rafael.suarez@uv.es). Department of Business Mathematics
University of Valencia (Spain)